Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/spreed.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2021-02-25 16:39:53 +0300
committerJoas Schilling <coding@schilljs.com>2021-03-08 13:56:18 +0300
commit6184127a50ad62e429600e2d6cc0310d2873af6d (patch)
tree58bdf97f1689021ccee910b6ea4ce61b24ce7a16 /src/mixins
parenta545cff72b2249258de51b6ce3d979e6d22a090b (diff)
Make the UI handle the call state on it's interactions instead of the participant data
The user could have joined the call in another window/device and shouldn't jump to the call view for this window unless the user pressed "Join call" here as well Signed-off-by: Joas Schilling <coding@schilljs.com>
Diffstat (limited to 'src/mixins')
-rw-r--r--src/mixins/isInCall.js7
1 files changed, 2 insertions, 5 deletions
diff --git a/src/mixins/isInCall.js b/src/mixins/isInCall.js
index f8a105984..1cac7efc8 100644
--- a/src/mixins/isInCall.js
+++ b/src/mixins/isInCall.js
@@ -19,14 +19,11 @@
*
*/
-import { PARTICIPANT } from '../constants'
import SessionStorage from '../services/SessionStorage'
import { EventBus } from '../services/EventBus'
/**
* A mixin to check whether the current session of a user is in a call or not.
*
* Components using this mixin require a "participant" property with, at least, the "inCall" property.
*/
export default {
@@ -39,7 +36,7 @@ export default {
computed: {
isInCall() {
return this.sessionStorageJoinedConversation === this.$store.getters.getToken()
- && this.participant.inCall !== PARTICIPANT.CALL_FLAG.DISCONNECTED
+ && this.$store.getters.isInCall(this.$store.getters.getToken())
},
},
@@ -19,14 +19,11 @@
import { EventBus } from '../services/EventBus'
/**
- * A mixin to check whether the current session of a user is in a call or not.
- *
- * Components using this mixin require a "participant" property with, at least, the "inCall" property.
+ * A mixin to check whether the user joined the call of the current token in this PHP session or not.
*/
export default {